@@ -1,6 +1,6 @@
 import sys
-# sys.path.insert(0, './src')
-# sys.path.insert(0, '../src')
+sys.path.insert(0, './src')
+sys.path.insert(0, '../src')
 
 # import form pip package
 import pgos_cli
@@ -10,6 +10,8 @@ import os
 import json
 
 pgos_cli_client = PgosCliClient()
+pgos_cli_client.SetSecretKey("your_server_secret_key")
+pgos_cli_client.SetTitleRegion("your_title_region_id")
 
 def GenParamsJsonPath(command_name):
     # params_file_name = command_name + '.json'
